<?xml version="1.0" encoding="UTF-8"?>
<!--
  - This is a cleanup script that does a few things:
  - - ensures that the 'root' page is the generated "toc.xml" page
  - - ensures that somewhere in the list of pages is the generated "artifacts.xml" page
  - - places a list of all artifacts (ordered by order of table of contents) as pages beneath artifacts.xml
  - - strips the igpublisher-spreadsheet extensions, if any
  - If dealing with a multi-version IG, it will be run against both IG versions.
  -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:html="http://www.w3.org/1999/xhtml" xmlns="http://www.w3.org/1999/xhtml" xmlns:f="http://hl7.org/fhir" exclude-result-prefixes="html f">
  <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
  <xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>
  <xsl:template match="f:extension[@url='http://hl7.org/fhir/StructureDefinition/igpublisher-spreadsheet']"/>
  <xsl:template match="f:grouping">
    <xsl:if test="parent::f:definition/f:resource/f:groupingId[@value=current()/@id]">
      <xsl:copy>
        <xsl:apply-templates select="@*|node()"/>
      </xsl:copy>
    </xsl:if>
  </xsl:template>
  <xsl:template match="f:definition">
    <!-- If we've defined the groups, then we sort based on the groups, then alphabetically -->
    <xsl:choose>
      <xsl:when test="f:group[starts-with(@id, '_')]">
        <xsl:copy>
          <xsl:apply-templates select="@*|f:extension|f:modifierExtension|f:grouping|comment()[not(preceding-sibling::f:resource)]"/>
          <xsl:for-each select="f:grouping">
            <xsl:choose>
              <xsl:when test="starts-with(@id, '_')">
                <xsl:for-each select="parent::f:definition/f:resource[f:groupingId/@value=current()/@id]">
                  <xsl:sort select="f:name/@value"/>
                  <xsl:sort select="f:reference/f:reference/@value"/>
                  <xsl:apply-templates select="."/>
                </xsl:for-each>
              </xsl:when>
              <xsl:otherwise>
                <xsl:for-each select="parent::f:definition/f:resource[f:groupingId/@value=current()/@id]">
                  <xsl:apply-templates select="."/>
                </xsl:for-each>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:for-each>
        </xsl:copy>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy>
          <xsl:apply-templates select="@*|node()"/>
        </xsl:copy>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template match="f:ImplementationGuide/f:definition/f:page">
    <xsl:copy>
      <xsl:choose>
        <xsl:when test="f:nameUrl/@value='toc.html' and f:generation/@value='html'">
          <xsl:apply-templates select="@*|node()"/>
        </xsl:when>
        <xsl:otherwise>
          <nameUrl xmlns="http://hl7.org/fhir" value="toc.html"/>
          <title xmlns="http://hl7.org/fhir" value="Table of Contents"/>
          <generation xmlns="http://hl7.org/fhir" value="html"/>
          <page xmlns="http://hl7.org/fhir">
            <xsl:apply-templates select="@*|node()[not(self::f:page)]"/>
          </page>
          <xsl:apply-templates select="f:page"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:if test="not(descendant-or-self::f:page[f:nameUrl/@value='artifacts.html'])">
        <page xmlns="http://hl7.org/fhir">
          <nameUrl value="artifacts.html"/>
          <title value="Artifacts Summary"/>
          <generation value="html"/>
          <xsl:call-template name="artifactPages"/>
        </page>
      </xsl:if>
    </xsl:copy>
  </xsl:template>
  <xsl:template match="f:page[f:nameUrl/@value='artifacts.html']">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
      <xsl:call-template name="artifactPages"/>
    </xsl:copy>
  </xsl:template>
  <xsl:template name="artifactPages">
    <xsl:for-each select="/f:ImplementationGuide/f:definition/f:grouping">
      <xsl:for-each select="parent::f:definition/f:resource[f:groupingId/@value=current()/@id]">
        <page xmlns="http://hl7.org/fhir">
          <nameUrl value="{f:extension[@url='http://hl7.org/fhir/StructureDefinition/implementationguide-page']/f:valueUri/@value}"/>
          <title value="{f:name/@value}"/>
          <generation value="generated"/>
        </page>      
      </xsl:for-each>
    </xsl:for-each>
  </xsl:template>
</xsl:stylesheet>  